/*
* Copyright (C) 2003 Christian Nitschkowski <segfault_ii@web.de>
*/

#include <stdlib.h>

#include <qdir.h>

#include <kaboutdata.h>
#include <kcmdlineargs.h>
#include <kdesktopfile.h>
#include <kglobal.h>
#include <klocale.h>
#include <kstandarddirs.h>
#include <kuniqueapplication.h>

#include "oooqs.h"

static const char description[] =
    I18N_NOOP( "The OpenOffice.org Quickstarter for KDE" );

static const char version[] = "2.0";

static KCmdLineOptions options[] =
    {
        { "autostart",
          I18N_NOOP( "OpenOffice.org Quickstarter "
                     "should check if autostart is enabled" ), 0 },
        KCmdLineLastOption
    };

int main( int argc, char **argv ) {
	KDesktopFile * autostart = 0;
	OOoQs *mainWin = 0;
	QString autostartFile;
	int returnValue;

	KAboutData about( "oooqs",
	                  I18N_NOOP( "OpenOffice.org Quickstarter" ),
	                  version, description, KAboutData::License_GPL,
	                  "(C) 2003 Christian Nitschkowski",
	                  0, 0, "segfault_ii@web.de" );
	about.addAuthor( "Christian Nitschkowski",
	                 0, "segfault_ii@web.de" );

	KCmdLineArgs::init( argc, argv, &about );
	KCmdLineArgs::addCmdLineOptions( options );

	KUniqueApplication app;

	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

	/**
	Get the path where the autostart-file should be.
	*/
	autostartFile = KGlobal::dirs() ->localkdedir()
	                + QDir::separator() + "Autostart"
	                + QDir::separator() + "oooqs.desktop";

	/**
	Try to find the autostart-file.
	If it's not there, create it.
	*/
	if ( !QDir( autostartFile ).exists() ) {
		/**
		Create autostart-link.
		*/
		autostart = new KDesktopFile( autostartFile );
		autostart->writeEntry( "Exec", "oooqs --autostart" );
		autostart->writeEntry( "Encoding", "UTF-8" );
		autostart->writeEntry( "Name", about.programName() );
		autostart->writeEntry( "Type", "Application" );
		autostart->writeEntry( "Icon", "oooqs" );
		autostart->sync();
		delete autostart;
		}

	if ( args->isSet( "autostart" ) ) {
		KGlobal::config() ->setGroup( "General" );
		if ( !KGlobal::config() ->readBoolEntry( "Autostart", true ) ) {
		/**
		Return with an errorcode as defined in stdlib.h
		*/
			return EXIT_SUCCESS;
			}
		}

	/**
	Disable the regular session management.
	OOoQs takes care for itself if it should be restarted
	on login.
	*/
	app.disableSessionManagement();

	mainWin = new OOoQs();
	if ( !mainWin->okToRun() ) {
		delete mainWin;
		/**
		Return with an errorcode as defined in stdlib.h
		*/
		return EXIT_FAILURE;
		}

	app.setMainWidget( mainWin );
	mainWin->show();

	args->clear();

	returnValue = app.exec();
	/**
	Delete the mainwindow manually to make sure the destructor is
	called and the user asked for remaining soffice-instances.
	*/
	delete mainWin;

	return returnValue;
	}
